summaryrefslogtreecommitdiffstats
path: root/src/itemlibrary.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/itemlibrary.h')
-rw-r--r--src/itemlibrary.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/itemlibrary.h b/src/itemlibrary.h
index 181eb5f..5f0e39f 100644
--- a/src/itemlibrary.h
+++ b/src/itemlibrary.h
@@ -11,8 +11,8 @@
#ifndef ITEMLIBRARY_H
#define ITEMLIBRARY_H
-#include <qcolor.h>
-#include <qmap.h>
+#include <tqcolor.h>
+#include <tqmap.h>
class Document;
class Item;
@@ -21,8 +21,8 @@ class ItemLibrary;
class LibraryItem;
inline ItemLibrary* itemLibrary();
-typedef QMap< QString, QImage > ImageMap;
-typedef QValueList<LibraryItem*> LibraryItemList;
+typedef TQMap< TQString, TQImage > ImageMap;
+typedef TQValueList<LibraryItem*> LibraryItemList;
/**
While the program is running, only one instance of this class is created.
@@ -35,9 +35,9 @@ class ItemLibrary
public:
~ItemLibrary();
/**
* Returns a QPixmap of the item icon
*/
- QPixmap itemIconFull( const QString &id );
+ TQPixmap itemIconFull( const TQString &id );
/**
* Append the given item into the library
*/
@@ -49,15 +49,15 @@ public:
/**
* Creates a new item with the given id, and returns a pointer to it
*/
- Item *createItem( const QString &id, ItemDocument *itemDocument, bool newItem, const char *newId = 0L, bool finishCreation = true );
+ Item *createItem( const TQString &id, ItemDocument *itemDocument, bool newItem, const char *newId = 0L, bool finishCreation = true );
/**
* Returns an image of the given cnitem. As QPixmap::convertToImage is
* a *very* slow function, this will cache the result and return that for
* large images.
* @param cnItem A pointer to the CNItem
* @param maxSize The maximum size (in pixels) before the image is cached
*/
- QImage itemImage( Item *item, const uint maxSize = 36000 );
+ TQImage itemImage( Item *item, const uint maxSize = 36000 );
protected:
void addComponents();
@@ -35,9 +35,9 @@ class ItemLibrary
~ItemLibrary();
/**
- * Returns a QPixmap of the item icon
+ * Returns a TQPixmap of the item icon
*/
@@ -49,15 +49,15 @@ public:
/**
- * Returns an image of the given cnitem. As QPixmap::convertToImage is
+ * Returns an image of the given cnitem. As TQPixmap::convertToImage is
* a *very* slow function, this will cache the result and return that for
* large images.